package cz.upol.wall;

import javafx.beans.property.IntegerProperty;
import javafx.beans.property.SimpleIntegerProperty;

/**
 * Trida reprezentuje mic na plose dany souradnicemi (r, c),
 * tj. radek + sloupec.
 */
public class Ball {
	
	/** Radek na nemz se mic vyskytuje */
	private IntegerProperty row;
	
	/** Sloupec na nemz se mic vyskytuje */
	private IntegerProperty column;
	
	/**
	 * Vertikalni smer, kterym se mic pohybuje, tato hodnota je
	 * po zavolani metody {@link #update()} prictena k hodnote {@link #row}
	 */
	private int rDir = -1;
	
	/**
	 * Horizontalni smer, kterym se mic pohybuje, tato hodnota je
	 * po zavolani metody {@link #update()} prictena k hodnote {@link #column}
	 */
	private int cDir = -1;
	
	/**
	 * Vytvori mic na danych souradnich
	 * @param r -- radek
	 * @param c -- sloupec
	 */
	public Ball(int r, int c) {
		row = new SimpleIntegerProperty(r);
		column = new SimpleIntegerProperty(c);
	}
	
	/**
	 * Odrazi mic od vodorovne prekazky
	 */
	public void vBounce() {
		rDir *= -1;
	}
	
	/**
	 * Odrazi mic od vertikalni prekazky
	 */
	public void hBounce() {
		cDir *= -1;
	}
	
	/**
	 * Posunu mic po dane trejektorii
	 */
	public void update() {
		setRow(getRow() + rDir);
		setColumn(getColumn() + cDir);
	}
	
	/**
	 * Nastavi mici pocatecni smer
	 */
	public void initializeDirection() {
		rDir = -1;
		cDir = -1;
	}
	
	//
	// Vlastnosti vyuzivane JavaFX
	//

	public final IntegerProperty rowProperty() {
		return this.row;
	}
	
	public final int getRow() {
		return this.rowProperty().get();
	}
	
	public final void setRow(final int row) {
		this.rowProperty().set(row);
	}
	
	public final IntegerProperty columnProperty() {
		return this.column;
	}
	
	public final int getColumn() {
		return this.columnProperty().get();
	}
	
	public final void setColumn(final int column) {
		this.columnProperty().set(column);
	}
}
